@@ -6,7 +6,7 @@ class Bring:
     Unofficial Bring API interface.
     """
 
-    def __init__(self, mail, password):
+    def __init__(self, mail, password, headers = None):
         self.mail = mail
         self.password = password
         self.url = 'https://api.getbring.com/rest/v2/'
@@ -14,14 +14,18 @@ class Bring:
         self.name = ''
         self.bearerToken = ''
         self.refreshToken = ''
-        self.headers = {
-            'Authorization': '',
-            'X-BRING-API-KEY': 'cof4Nc6D8saplXjE3h3HXqHH8m7VU2i1Gs0g85Sp',
-            'X-BRING-CLIENT-SOURCE': 'webApp',
-            'X-BRING-CLIENT': 'webApp',
-            'X-BRING-COUNTRY': 'DE',
-            'X-BRING-USER-UUID': ''
-        }
+
+        if headers:
+            self.headers = headers
+        else:
+            self.headers = {
+                'Authorization': '',
+                'X-BRING-API-KEY': 'cof4Nc6D8saplXjE3h3HXqHH8m7VU2i1Gs0g85Sp',
+                'X-BRING-CLIENT-SOURCE': 'webApp',
+                'X-BRING-CLIENT': 'webApp',
+                'X-BRING-COUNTRY': 'DE',
+                'X-BRING-USER-UUID': ''
+            }
         self.putHeaders = {
             'Authorization': '',
             'X-BRING-API-KEY': '',
@@ -105,6 +109,30 @@ class Bring:
             traceback.print_exc()
             raise
 
+
+    def getAllItemDetails(self, listUuid):
+        """
+        Get all details from a shopping list.
+
+        Parameters
+        ----------
+        listUuid : str
+            A list uuid returned by loadLists()
+
+        Returns
+        -------
+        list
+            The JSON response as a list.
+        """
+        try:
+            r = requests.get(f'{self.url}bringlists/{listUuid}/details', headers = self.headers);
+            return r.json();
+        except:
+            print(f'Exception: Cannot get item details for list {listUuid}:')
+            traceback.print_exc()
+            raise
+
+
     def saveItem(self, listUuid, itemName, specification=''):
         """
         Save an item to a shopping list.
